All Classes and Interfaces

Class
Description
A FASTA formatted sequence.
This class gives public API to RONN functions.
Holder for the ranges, contain pointers to starting and ending position on the sequence which comprises a disordered region.
Class that loads data from the model files into ModelLoader.Model objects
Represent a RONN model
Represents a Threshold
The stream that void its input
Fully re-factored and enhanced version of RONN.
Fully re-factored version of RONN model.
 
A collection of various constrain values used by RONN
 
Utility class for operations on sequences
A simple timer, calculates the time interval between two events.